@@ -24,6 +24,7 @@ addAMRUrl = ''
 imageUrl = ''
 originUrl = ''
 ttsVoiceUrl = ''
+RobotQQ = ''
 
 messageType = {
     '1'     : '好友',
@@ -35,11 +36,11 @@ messageType = {
 }
 color = ['\033[31m', '\033[32m', '\033[33m', '\033[34m', '\033[35m', '\033[36m', '\033[37m']
 quitGroupList = []
-systemMenu = '管理员菜单：\n\\线程数目（检测当前线程，测试压力）\n\\检测管理（逐一检测群聊管理，退出非管理群聊）\n\\更新歌单（添加MP3格式文件后执行更新歌单）\n\\更新图片（添加图片后执行，图片名称即为匹配的关键字，格式为*jpg）\n\\自定义好友欢迎消息-\n\\自定义群聊欢迎消息-\n\\自定义群聊退出消息-\n\n含有-即为带参指令，-后填写参数\n例如：自定义好友欢迎消息-你好，我是天依'
+systemMenu = '管理员菜单：\n\\线程数目（检测当前线程，测试压力）\n\\检测管理（逐一检测群聊管理，退出非管理群聊）\n\\更新歌单（添加MP3格式文件后执行更新歌单）\n\\更新图片（添加图片后执行，图片名称即为匹配的关键字，格式为*jpg）\n\\自定义好友欢迎消息-\n\\自定义群聊欢迎消息-\n\\自定义群聊退出消息-\n\n含有-即为带参指令，-后填写参数\n例如：\\自定义好友欢迎消息-你好，我是天依'
 
 # 机器人基础属性
 class myRobot():
-    def __init__(self, myApiUrl, myTTSUrl, myTianXingKey, mymyQQurl):
+    def __init__(self, myApiUrl, myTTSUrl, myTianXingKey, mymyQQurl, myRobotQQ):
         global apiUrl
         global TTSUrl
         global TianXingKey
@@ -48,14 +49,16 @@ class myRobot():
         global imageUrl
         global originUrl
         global ttsVoiceUrl
+        global RobotQQ
         apiUrl = myApiUrl
         TTSUrl = myTTSUrl
         TianXingKey = myTianXingKey
         addMp3Url = mymyQQurl + 'Voice/Music/MP3/'
         addAMRUrl = mymyQQurl + 'Voice/Music/AMR/'
-        imageUrl = mymyQQurl + 'Voice/Origin/'
-        originUrl = mymyQQurl + 'Image/'
+        originUrl = mymyQQurl + 'Voice/Origin/'
+        imageUrl = mymyQQurl + 'Image/'
         ttsVoiceUrl = mymyQQurl + 'Voice/'
+        RobotQQ = myRobotQQ
 
 # 初始化音频
 def originAudio(fileName, auidoMessage):
@@ -199,7 +202,7 @@ def systemSetting(myThread):
         sendMsg_friend(myThread, myThread.recFromQQ, sendMsg)
     elif myThread.recMsg == '检测管理':
         global quitGroupList
-        timeThread_temp = timeThread('2327541179', False)
+        timeThread_temp = timeThread('3262594471', False)
         timeThread_temp.start()
         timeThread_temp.join()
         sendMsg = '已退出群聊：\n'
@@ -282,7 +285,7 @@ def sendMsg_Group(myThread, sendNum, sendMsg):
         }
     }
     requests.post(apiUrl, json=sendMsgData)
-    msg = myThread.name + '：向' + getFriendsRemark(myThread) + '(' + sendNum + ')发送' + sendMsg
+    msg = myThread.name + '：向' + getFriendsRemark(myThread) + '(' + sendNum + ')发送：' + sendMsg
     print(myThread.wordColor(msg))
 def sendMsg_Group_QQ(robotQQ, sendNum, sendMsg):
     sendMsgData = {
@@ -297,6 +300,23 @@ def sendMsg_Group_QQ(robotQQ, sendNum, sendMsg):
         }
     }
     requests.post(apiUrl, json=sendMsgData)
+def sendMsg_Long_Group(myThread, sendNum, sendMsg):
+    sendMsgData = {
+        'function'  : 'Api_SendLongMsg',
+        'token'     : '666',
+        'params'    : {
+            'c1'        : myThread.recRobot,
+            'c2'        : 0,
+            'c3'        : 2,
+            'c4'        : sendNum,
+            'c5'        : '',
+            'c6'        : sendMsg,
+            'c7'        : 0
+        }
+    }
+    requests.post(apiUrl, json=sendMsgData)
+    msg = myThread.name + '：向' + getFriendsRemark(myThread) + '(' + sendNum + ')发送' + sendMsg
+    print(myThread.wordColor(msg))
 
 # 字典类型数据None数据处理功能
 def dict_clean(items):
@@ -435,15 +455,17 @@ def prepareVoice(myThread):
 
 # 判断 @
 def judgeAt(recMsg):
-    if recMsg[0:13] == '[@2327541179]':
+    RobotQQLen = len(RobotQQ)
+    if recMsg[0 : (RobotQQLen + 3)] == '[@'+ RobotQQ +']':
         return True
     else:
         return False
 
 # 除去 @
 def deleteAt(recMsg):
+    RobotQQLen = len(RobotQQ)
     msgLen = len(recMsg)
-    recMsg = recMsg[14:msgLen]
+    recMsg = recMsg[(RobotQQLen + 4) : msgLen]
     return recMsg
 
 # 同意好友添加
@@ -720,16 +742,20 @@ def Music_readMusicName(path, format):
 # Mp3 转 Amr 主程序
 def Music_Mp3toAMRMain(myThread):
     musicNameListmp3 = Music_readMusicName(addMp3Url, '*mp3')
-    musicNameListAMR = Music_readMusicName(addAMRUrl, '*amr')
     sendMsg = '音频转化已完成：\n'
     for i in musicNameListmp3:
+        if not Music_JudgeMusic(i):
+            i = Music_getMusicName(i)
+            Music_Mp3toAMR(i)
+            sendMsg = sendMsg + i +'\n'
+            msg = i + '-已添加完成'
+            sendMsg_friend(myThread, myThread.recFromQQ, msg)
+    musicNameListAMR = Music_readMusicName(addAMRUrl, '*amr')
+    musicNameList = []
+    for i in musicNameListAMR:
         i = Music_getMusicName(i)
-        Music_Mp3toAMR(i)
-        musicNameListAMR.append(i)
-        sendMsg = sendMsg + i +'\n'
-        msg = i + '以添加完成'
-        sendMsg_friend(myThread, myThread.recFromQQ, msg)
-    Music_addMusicTXT(musicNameListAMR)
+        musicNameList.append(i)
+    Music_addMusicTXT(musicNameList)
     sendMsg_friend(myThread, myThread.recFromQQ, sendMsg)
     msg = myThread.name + '：音频转化完成'
     print(myThread.wordColor(msg))
@@ -737,14 +763,15 @@ def Music_Mp3toAMRMain(myThread):
 # 展示歌单
 def Music_showMenu(myThread):
     musicList = Music_readMusicTXT()
-    msg = '歌单如下：\n'
+    menuMsg = '歌单如下：\n'
     for i in musicList:
-        msg = msg + '《' + i + '》'
-    msg = msg + '\n如果想要天依唱歌，请发送“唱+歌名”，如：唱亲爱的'
+        menuMsg = menuMsg + '《' + i + '》'
+    menuMsg = menuMsg + '\n如果想要天依唱歌，请发送唱+歌名，如：唱亲爱的'
+    print(menuMsg)
     if myThread.recType == 1:
-        sendMsg_friend(myThread, myThread.recFromQQ, msg)
-    else:
-        sendMsg_Group(myThread, myThread.recID, msg)
+        sendMsg_friend(myThread, myThread.recFromQQ, menuMsg)
+    elif myThread.recType == 2:
+        sendMsg_Group(myThread, myThread.recID, menuMsg)
 
 # 判断曲目是否在歌单中
 def Music_JudgeMusic(musicName):
